# pleroma.py

Small aiohttp-based wrapper around the Mastodon/Pleroma API. Deliberately does not cover all endpoints. More endpoints will be added as I need them.

## License

AGPL 3.0 only, see LICENSE.md.
